print.SensSpec: Print method for 'SensSpec' objects

print.SensSpecR Documentation

Print method for SensSpec objects

Description

Prints the results for an object of class SensSpec.

Usage

## S3 method for class 'SensSpec'
print(x, ...)

Arguments

x

An object of class SensSpec.

...

Further arguments (currently not used).

Details

Prints the sensitivity and specificity results stored in a SensSpec object.

Value

No return value, called for side effects.

See Also

SensSpec, print

Examples

## Load example data
data(VanDyke)

## Return the first parts of an object
head(VanDyke)

## Extract unique modalities
unique(VanDyke$treatment)

## Extract Unique readers
unique(VanDyke$reader)

## Create binary test results (Y_ijk)
VanDyke$Y <- as.numeric(VanDyke$rating >= 3)

## Example usage of SensSpec function:
senspe_result1 <- SensSpec(data = VanDyke, Modality = treatment,
                           Reader = reader, Case = case,
                           D = truth, Y = Y, percentage = FALSE, digits = 3)
print(senspe_result1)

# Report results as percentage points
senspe_result2 <- SensSpec(data = VanDyke, Modality = treatment,
                           Reader = reader, Case = case,
                           D = truth, Y = Y, percentage = TRUE, digits = 1)
print(senspe_result2)


MRMCbinary documentation built on March 23, 2026, 5:07 p.m.