| MRMCbinary-package | R Documentation |
R package MRMCbinary is a package aimed at comparing the diagnostic performance of different modalities (i.e., sensitivities and specificities) in multi-reader multi-case (MRMC) studies with binary diagnostic test results.
Seungjae Lee seungjae2525@gmail.com and Woojoo Lee lwj221@gmail.com
Lee, S., Jang, S., and Lee, W. (2026). Evaluating Diagnostic Accuracy of Binary Medical Tests in Multi-Reader Multi-Case Study. Statistics in Medicine, 45(6–7), e70471. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1002/sim.70471")}
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.