View source: R/print.MRMCbinary.R
| print.MRMCbinary | R Documentation |
MRMCbinary objectsPrints the results for an object of class MRMCbinary.
## S3 method for class 'MRMCbinary'
print(x, ...)
x |
An object of class |
... |
Further arguments (currently not used). |
Prints the results from the conditional logistic regression (CLR) analysis.
In the printed CLR results, Estimate denotes the estimated log odds ratio and SE denotes its standard error.
When comparing specificities, the reported Estimate is based on the false positive fraction (FPF) among non-diseased cases.
Therefore, a positive Estimate implies lower specificity than the reference.
For interpretation on the specificity scale, use the negative of the reported Estimate.
No return value, called for side effects.
MRMCbinary, summary.MRMCbinary, print
## Load example data
data(VanDyke)
## Return the first parts of an object
head(VanDyke)
## Extract unique modalities
unique(VanDyke$treatment)
## Extract Unique readers
unique(VanDyke$reader)
## Create binary test results (Y_ijk)
VanDyke$Y <- as.numeric(VanDyke$rating >= 3)
## Example usage of MRMCbinary function:
# When comparing the sensitivities and specificities between modalities
modality_result <- MRMCbinary(data = VanDyke, Modality = treatment, Reader = reader,
Case = case, D = truth, Y = Y, measure = "All",
effect = "Modality", interaction = NULL,
reference.Modality = "1", reference.Reader = NULL)
print(modality_result)
# When comparing the sensitivities and specificities between readers
reader_result <- MRMCbinary(data = VanDyke, Modality = treatment, Reader = reader,
Case = case, D = truth, Y = Y, measure = "All",
effect = "Reader", interaction = NULL,
reference.Modality = NULL, reference.Reader = "1")
print(reader_result)
# When comparing the sensitivities and specificities
# between modalities and between readers together
# not considering interaction between modalities and readers
both_result_wo_int <- MRMCbinary(data = VanDyke, Modality = treatment, Reader = reader,
Case = case, D = truth, Y = Y, measure = "All",
effect = "Both", interaction = FALSE,
reference.Modality = "1", reference.Reader = "1")
print(both_result_wo_int)
# When comparing the sensitivities and specificities
# between modalities and between readers together
# considering interaction between modalities and readers
both_result_with_int <- MRMCbinary(data = VanDyke, Modality = treatment, Reader = reader,
Case = case, D = truth, Y = Y, measure = "All",
effect = "Both", interaction = TRUE,
reference.Modality = "1", reference.Reader = "1")
print(both_result_with_int)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.